//
//  SBSDKBarcodeAdditionalParameters.swift
//  barcode_scanner
//
//  Created by Yevgeniy Knizhnik on 13.07.21.
//

import Foundation
import ScanbotBarcodeScannerSDK

extension SBSDKBarcodeAdditionalParameters {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        
        if let value = dictionary["enableGS1Decoding"] as? Bool {
            self.enableGS1Decoding = value
        }
        
        if let value = dictionary["minimumTextLength"] as? UInt {
            self.minimumTextLength = value
        }
        
        if let value = dictionary["maximumTextLength"] as? UInt {
            self.maximumTextLength = value
        }
        
        if let value = dictionary["minimum1DBarcodesQuietZone"] as? UInt {
            self.minimum1DBarcodesQuietZone = value
        }
        
        if let value = dictionary["stripCheckDigits"] as? Bool {
            self.stripCheckDigits = value
        }
        
        if let value = dictionary["codeDensity"] as? String {
            self.codeDensity = extractBarcodeDensityFrom(string: value)
        }
        
        switch dictionary["msiPlesseyChecksumAlgorithm"] as? String  {
        case "None":
            self.msiPlesseyChecksumAlgorithm = .none
        case "Mod10":
            self.msiPlesseyChecksumAlgorithm = .mod10
        case "Mod11IBM":
            self.msiPlesseyChecksumAlgorithm = .mod11IBM
        case "Mod11NCR":
            self.msiPlesseyChecksumAlgorithm = .mod11NCR
        case "Mod1010":
            self.msiPlesseyChecksumAlgorithm = .mod1010
        case "Mod1110IBM":
            self.msiPlesseyChecksumAlgorithm = .mod1110IBM
        case "Mod1110NCR":
            self.msiPlesseyChecksumAlgorithm = .mod1110NCR
        default:
            self.msiPlesseyChecksumAlgorithm = .mod10
        }
    }
    
    /**
     extract the barcode density from the json string
     */
    func extractBarcodeDensityFrom(string: String) -> SBSDKBarcodeDensity {
        var codeDensity: SBSDKBarcodeDensity = .low
        if string == "HIGH"{
            codeDensity = .high
        }
        return codeDensity;
    }
}
