import 'package:barcode_scanner/barcode_scanning_data.dart';
import 'package:flutter/widgets.dart';
import 'package:json_annotation/json_annotation.dart';

import '../common_data.dart';
import 'finder.dart';

part 'camera_configuration.g.dart';

abstract class CameraConfiguration {
  Map<String, dynamic> toJson();
}

/// The finder view is a rectangular overlay view that clips the camera view, so that the detection will focus just a specific area.
/// You can specify the size and positioning, as well as other UI properties.
/// Set this property to `true` if you want to use the Finder View, `false` otherwise (default: false)
@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class FinderConfiguration {
  /// The shape by which background will be clipped and which will be presented as finder hole
  @JsonKey(ignore: true)
  BoxDecoration decoration;

  /// This widget will be drawn on top of the finder hole.
  /// Here you can add some custom design, for example, with qr code placeholder
  @JsonKey(ignore: true)
  Widget? widget;

  /// Something that should be shown between top of the finder and camera
  @JsonKey(ignore: true)
  Widget? topWidget;

  /// Something that should be shown between bottom of the finder and camera
  @JsonKey(ignore: true)
  Widget? bottomWidget;

  /// The overlay background color, around the finder view rectangle
  @JsonKey(ignore: true)
  Color? backgroundColor;

  /// The finder view rectangle aspect ratio
  FinderAspectRatio? finderAspectRatio;

  /// The finder view minimum padding from the bounds of the screen
  double finderMinimumPadding;

  /// The finder view Insets
  FinderInsets? finderInsets;

  /// triggers when the finder area is changed, it helpfull to align some content on tom of the finder
  @JsonKey(ignore: true)
  final OnFinderRectChange? onFinderRectChange;

  FinderConfiguration(
      {required this.decoration,
      this.backgroundColor,
      this.finderAspectRatio = const FinderAspectRatio(width: 1, height: 2),
      this.finderMinimumPadding = 20,
      this.widget,
      this.topWidget,
      this.bottomWidget,
      this.onFinderRectChange,
      this.finderInsets =
          const FinderInsets(left: 20, top: 20, right: 20, bottom: 20)});

  Map<String, dynamic> toJson() => _$FinderConfigurationToJson(this);
}
